@@ -39,6 +39,9 @@ instance confident that if it were being called directly no indent would be
 applied but if module A was calling it then it's output would be indented
 one level.
 
+=for testing
+use_ok('Text::Indent');
+
 =cut
 
 package Text::Indent;
@@ -46,7 +49,7 @@ package Text::Indent;
 use strict;
 use warnings;
 
-our $VERSION = '0.033';
+our $VERSION = 0.001_000;
 
 use Params::Validate    qw|:all|;
 
@@ -96,6 +99,15 @@ singleton instance returned by the B<instance> accessor. Defaults to TRUE.
 
 =back
 
+=begin testing
+
+eval { Text::Indent->new };
+ok( ! $@, "can create an object");
+eval {  Text::Indent->new( Foo => 'Bar' ) };
+ok( $@, "constructor dies on invalid args");
+
+=end testing
+
 =cut
 
 sub init
@@ -168,6 +180,14 @@ sub instance
 This method increases the level of indentation by $how_many levels.  If
 not provided, $how_many defaults to 1.
 
+=for testing
+my $i = Text::Indent->new;
+is( $i->level, 0, "level initialized to 0");
+$i->increase;
+is( $i->level, 1, "level increased to 1");
+$i->increase(2);
+is( $i->level, 3, "level increased to 3");
+
 =cut
 
 sub increase
@@ -187,6 +207,14 @@ sub increase
 This method decreases the level of indentation by $how_many levels.  If
 not provided, $how_many defaults to 1.
 
+=for testing
+my $i = Text::Indent->new( Level => 5 );
+is( $i->level, 5, "level initialized to 5");
+$i->decrease;
+is( $i->level, 4, "level decreased to 4");
+$i->decrease(2);
+is( $i->level, 2, "level decreased to 2");
+
 =cut
 
 sub decrease
@@ -204,7 +232,13 @@ sub decrease
 =head2 reset
 
 This method resets the level of indentation to 0.  It is functionally
-equivalent to $indent->level(0).
+equivalent to $ident->level(0).
+
+=for testing
+my $i = Text::Indent->new( Level => 5 );
+is( $i->level, 5, "level initialized to 5");
+$i->reset;
+is( $i->level, 0, "level reset to 0");
 
 =cut
 
@@ -241,6 +275,22 @@ is set.
 
 If the indent level drops is a negative value, no indent is applied.
 
+=for testing
+my $i = Text::Indent->new;
+is( $i->indent("foo"), "foo\n", "no indentation");
+$i->increase;
+is( $i->indent("foo"), "  foo\n", "indent level 1");
+$i->spaces(4);
+is( $i->indent("foo"), "    foo\n", "change spaces to 4");
+$i->spacechar("+");
+is( $i->indent("foo"), "++++foo\n", "chance spacechar to +");
+$i->add_newline(0);
+is( $i->indent("foo"), "++++foo", "unset add_newline");
+$i->reset;
+is( $i->indent("foo"), "foo", "reset indent level");
+$i->decrease;
+is( $i->indent("foo"), "foo", "negative indent has no effect");
+
 =cut
 
 sub indent
@@ -249,8 +299,8 @@ sub indent
     my $self = shift;
     my @args = @_;
     
-    return ($self->spacechar x ($self->spaces * ($self->level < 0 ? 0 : $self->level))) .
-           "@args" . ($self->add_newline ? "\n" : '');
+    return ($self->spacechar x ($self->spaces * $self->level)) .
+           "@args" . ($self->add_newline ? "\n" : undef);
     
 }
 
@@ -263,6 +313,17 @@ __END__
 
 =head1 ACCESSORS
 
+=for testing
+my @accessors = qw|
+    spaces
+    spacechar
+    level
+    add_newline
+|;
+for( @accessors ) {
+    can_ok('Text::Indent', $_);
+}
+
 =head2 spaces
 
 Gets or sets the number of spaces used for each indent level.
@@ -306,7 +367,7 @@ In Bar.pm:
    return $i->indent("bar");
  }
 
-The output from the preceding example would be (> indicates the left edge
+The output from the preceeding example would be (> indicates the left edge
 of output and is for illustrative purposes only):
 
  >  foo
@@ -320,7 +381,7 @@ James FitzGibbon, E<lt>jfitz@CPAN.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-10 James FitzGibbon.  All Rights Reserved.
+Copyright (c) 2003 James FitzGibbon.  All Rights Reserved.
 
 This module is free software; you may use it under the same terms as Perl
 itself.
